@@ -19,7 +19,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "config.h"
+#include <config.h>
 
 #include <math.h>
 #include <stdlib.h>
@@ -103,7 +103,7 @@ pango_cairo_win32_font_get_font_face (PangoCairoFont *font)
        * we can't proceed at that point
        */
       if (!cwfont->font_face)
-	g_error ("Unable create Cairo font");
+	g_error ("Unable to create Win32 cairo font face.\nThis means out of memory or a cairo/fontconfig/FreeType bug");
     }
   
   return cwfont->font_face;
@@ -128,7 +128,7 @@ pango_cairo_win32_font_get_scaled_font (PangoCairoFont *font)
        * we can't proceed at that point
        */
       if (!cwfont->scaled_font)
-	g_error ("Unable create Cairo font");
+	g_error ("Unable to create Win32 cairo scaled font.\nThis means out of memory or a cairo/fontconfig/FreeType bug");
     }
   
   return cwfont->scaled_font;
@@ -138,7 +138,7 @@ pango_cairo_win32_font_get_scaled_font (PangoCairoFont *font)
  *    Method implementations    *
  ********************************/
 
-static void
+static gboolean
 pango_cairo_win32_font_install (PangoCairoFont *font,
 				cairo_t        *cr)
 {
@@ -154,6 +154,8 @@ static void
 cairo_font_iface_init (PangoCairoFontIface *iface)
 {
   iface->install = pango_cairo_win32_font_install;
+  iface->get_font_face = pango_cairo_win32_font_get_font_face;
+  iface->get_scaled_font = pango_cairo_win32_font_get_scaled_font;
 }
 
 G_DEFINE_TYPE_WITH_CODE (PangoCairoWin32Font, pango_cairo_win32_font, PANGO_TYPE_WIN32_FONT,
@@ -163,7 +165,7 @@ static void
 free_metrics_info (PangoWin32MetricsInfo *info)
 {
   pango_font_metrics_unref (info->metrics);
-  g_free (info);
+  g_slice_free (PangoWin32MetricsInfo, info);
 }
 
 static void
@@ -208,7 +210,7 @@ compute_glyph_extents (PangoFont        *font,
   logical_rect->width = 0;
   logical_rect->height = (font_extents.ascent + font_extents.descent) * PANGO_SCALE;
 
-  if (glyph)
+  if (glyph != PANGO_GLYPH_EMPTY)
     {
       cairo_glyph.index = glyph;
       cairo_glyph.x = 0;
@@ -345,7 +347,7 @@ pango_cairo_win32_font_get_metrics (PangoFont        *font,
       if (!win32font->fontmap)
 	return pango_font_metrics_new ();
 
-      info = g_new0 (PangoWin32MetricsInfo, 1);
+      info = g_slice_new0 (PangoWin32MetricsInfo);
       
       cwfont->metrics_by_lang = g_slist_prepend (cwfont->metrics_by_lang, 
 						 info);
